summaryrefslogtreecommitdiffstats
path: root/src/itdb.h
diff options
context:
space:
mode:
authorJorg Schuler <jcsjcs@users.sourceforge.net>2006-11-11 13:44:29 +0000
committerJorg Schuler <jcsjcs@users.sourceforge.net>2006-11-11 13:44:29 +0000
commit2cb1582ee12c459686deaef20647a2d5fa08f403 (patch)
tree1f47311e55dfd966f379d97008a5344408c9da70 /src/itdb.h
parentb261eb62e01147c3e4fb8dd8154bff007d6e15cc (diff)
downloadlibgpod-2cb1582ee12c459686deaef20647a2d5fa08f403.tar.gz
libgpod-2cb1582ee12c459686deaef20647a2d5fa08f403.tar.xz
libgpod-2cb1582ee12c459686deaef20647a2d5fa08f403.zip
* itdb.h: Itdb_Artwork:
- added unk028, unk036 and rating - added digitized_data timestamp - changed creation_date from gint32 to guint32 * db-itunes-parser.h: db-artwork-debug.c: MhiiHeader: - renamed unknown5 to rating - renamed digitised_date to digitized_date for conformity * db-artwork-writer.c (write_mhli): sanity check to avoid access of NULL pointer. (write_mhii): write unk028, rating, unk036, digitized_data * db-artwork_parser.c (parse_mhii): - parse unk028, rating, unk036, digitized data. - unified reading of DB_TYPE_PHOTO and DB_TYPE_ITUNES, got rid of parse_mhod() and parse_mhni(). git-svn-id: https://gtkpod.svn.sf.net/svnroot/gtkpod/libgpod/trunk@1335 f01d2545-417e-4e96-918e-98f8d0dbbcb6
Diffstat (limited to 'src/itdb.h')
-rw-r--r--src/itdb.h21
1 files changed, 15 insertions, 6 deletions
diff --git a/src/itdb.h b/src/itdb.h
index 0d0db75..b77743a 100644
--- a/src/itdb.h
+++ b/src/itdb.h
@@ -1,4 +1,4 @@
-/* Time-stamp: <2006-11-07 20:51:08 jcs>
+/* Time-stamp: <2006-11-11 16:29:02 jcs>
|
| Copyright (C) 2002-2006 Jorg Schuler <jcsjcs at users sourceforge net>
| Part of the gtkpod project.
@@ -445,11 +445,20 @@ struct _Itdb_Thumb {
};
struct _Itdb_Artwork {
- GList *thumbnails; /* list of Itdb_Thumbs */
- guint32 artwork_size; /* Size in bytes of the original source image */
- guint32 id; /* Artwork id used by photoalbums, starts at
- * 0x40... libgpod will set this on sync. */
- gint32 creation_date; /* Date the image was created */
+ GList *thumbnails; /* list of Itdb_Thumbs */
+ guint32 id; /* Artwork id used by photoalbums, starts at
+ * 0x40... libgpod will set this on sync. */
+ gint32 unk028;
+ guint32 rating; /* Rating from iPhoto * 20 (PhotoDB only) */
+ gint32 unk036;
+ guint32 creation_date; /* Date the image file was created
+ (creation date of image file (Mac type,
+ PhotoDB only) */
+ guint32 digitized_date;/* Date the image was taken (EXIF
+ information, Mac type, PhotoDB only) */
+ guint32 artwork_size; /* Size in bytes of the original source
+ image (PhotoDB only -- don't touch in
+ case of ArtworkDB!) */
/* below is for use by application */
guint64 usertype;
gpointer userdata;